@@ -95,7 +95,10 @@ update_os_data (GisPrivacyPage *page)
   if (g_file_get_contents ("/etc/os-release", &buffer, NULL, NULL))
     {
       name = get_item (buffer, "NAME");
-      privacy_policy = get_item (buffer, "PRIVACY_POLICY");
+      privacy_policy = get_item (buffer, "PRIVACY_POLICY_URL");
+      /* Fedora had PRIVACY_POLICY=... in os-release for a while, unfortunately */
+      if (!privacy_policy)
+        privacy_policy = get_item (buffer, "PRIVACY_POLICY");
       g_free (buffer);
     }
 
@@ -253,6 +256,8 @@ activate_link (GtkLabel       *label,
 
   view = webkit_web_view_new ();
   gtk_widget_set_size_request (view, 600, 500);
+  gtk_widget_set_hexpand (view, TRUE);
+  gtk_widget_set_vexpand (view, TRUE);
   g_signal_connect (view, "notify::estimated-load-progress",
                     G_CALLBACK (notify_progress_cb), progress_bar);
 
